@@ -7,7 +7,9 @@ from mqueue.util import Timer
 import mqueue
 
 class SchedulerThread(Timer):
-    interval = 20
+    @property
+    def interval(self):
+        return 60 - datetime.now().second + 1
     
     @log_error('Scheduler failed.', exc_info=True)
     def _run(self):
